@@ -3,6 +3,10 @@ from __future__ import annotations
 import asyncio
 import functools
 from abc import abstractmethod
+from collections import deque
+from datetime import timedelta
+from itertools import chain
+from operator import getitem
 from typing import (
     Any,
     AsyncIterable,
@@ -18,7 +22,6 @@ from typing import (
     overload,
 )
 
-
 from astream.stream import Stream
 from astream.utils import SentinelType, ensure_async_iterator, ensure_coro_fn, NoValueSentinel
 
@@ -128,44 +131,24 @@ def aflatmap(
     return Stream(iterable).aflatmap(fn)
 
 
-# @stream
-# def arange(start: int, stop: int | None = None, step: int = 1) -> Iterator[int]:
-#     """An asynchronous version of `range`.
-#
-#     Args:
-#         start: The start of the range.
-#         stop: The end of the range.
-#         step: The step of the range.
-#
-#     Yields:
-#         The next item in the range.
-#
-#     Examples:
-#         >>> async def demo_arange():
-#         ...     async for i in arange(5):
-#         ...         print(i)
-#         >>> asyncio.run(demo_arange())
-#         0
-#         1
-#         2
-#         3
-#         4
-#     """
-#     import time
-#
-#     if stop is None:
-#         stop = start
-#         start = 0
-#     for i in range(start, stop, step):
-#         time.sleep(1)
-#         yield i
-#         print(f"yielded {i}")
-#     print("done")
-
-
 arange = stream(range)
 
 
+@stream
+async def arange_delayed(
+    start: int,
+    stop: int | None = None,
+    step: int = 1,
+    delay: timedelta = timedelta(seconds=0.2),
+) -> AsyncIterator[int]:
+    if stop is None:
+        stop = start
+        start = 0
+    for i in range(start, stop, step):
+        yield i
+        await asyncio.sleep(delay.total_seconds())
+
+
 @stream
 async def amerge(*async_iters: AsyncIterable[_T]) -> AsyncIterator[_T]:
     """Merge multiple async iterators into one, yielding items as they are received.
@@ -298,6 +281,43 @@ async def areduce(
     return crt
 
 
+NoData = object()
+
+
+def dotget(path: str) -> Callable[[Any], Iterable[Any]]:
+    def _adotget(p: str, *objs: Any) -> Any:
+        if not p:
+            yield from objs
+
+        part, parts = p.split(".", maxsplit=1) if "." in p else (p, "")
+
+        matches = []
+        for obj in objs:
+
+            match obj:
+                case dict() if part in obj:
+                    matches.append(_adotget(parts, obj[part]))
+                case list() if part.isdigit() and int(part) < len(obj):
+                    matches.append(_adotget(parts, obj[int(part)]))
+                case dict() if part == "*":
+                    for v in obj.values():
+                        matches.append(_adotget(parts, v))
+                case list() if part == "*":
+                    for v in obj:
+                        matches.append(_adotget(parts, v))
+                case _ if (result := getattr(obj, part, NoData)) is not NoData:
+                    matches.append(_adotget(parts, result))
+                case _:
+                    pass
+
+        yield from chain.from_iterable(matches)
+
+    def _call(*objs: Any) -> Any:
+        return _adotget(path, *objs)
+
+    return _call
+
+
 __all__ = (
     "stream",
     "aenumerate",
@@ -310,4 +330,5 @@ __all__ = (
     "amerge",
     "ascan",
     "areduce",
+    "dotget",
 )
